@@ -437,68 +437,129 @@ IPPAPI(IppStatus, ippsHashMessage,(const Ipp8u* pMsg, int len, Ipp8u* pMD, IppHa
 IPP_DEPRECATED(MD5_DEPRECATED) \
 IPPAPI( const IppsHashMethod*, ippsHashMethod_MD5, (void) )
 IPPAPI( const IppsHashMethod*, ippsHashMethod_SM3, (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SM3_NI, (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SM3_TT, (void) )
 
 IPP_DEPRECATED(SHA1_DEPRECATED) \
-IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA1, (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA1,    (void) )
 IPP_DEPRECATED(SHA1_DEPRECATED) \
 IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA1_NI, (void) )
 IPP_DEPRECATED(SHA1_DEPRECATED) \
 IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA1_TT, (void) )
 
-IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA256, (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA256,    (void) )
 IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA256_NI, (void) )
 IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA256_TT, (void) )
 
-IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA224, (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA224,    (void) )
 IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA224_NI, (void) )
 IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA224_TT, (void) )
 
-IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512, (void) )
-IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA384, (void) )
-IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512_256, (void) )
-IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512_224, (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512,    (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512_NI, (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512_TT, (void) )
+
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA384,    (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA384_NI, (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA384_TT, (void) )
+
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512_256,    (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512_256_NI, (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512_256_TT, (void) )
+
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512_224,    (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512_224_NI, (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA512_224_TT, (void) )
+
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA3_224,    (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA3_256,    (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA3_384,    (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHA3_512,    (void) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHAKE128,    (int digestBitsize) )
+IPPAPI( const IppsHashMethod*, ippsHashMethod_SHAKE256,    (int digestBitsize) )
 
 IPPAPI( IppStatus, ippsHashMethodGetSize, (int* pSize) )
 IPP_DEPRECATED(MD5_DEPRECATED) \
 IPPAPI( IppStatus, ippsHashMethodSet_MD5, (IppsHashMethod* pMethod) )
 IPPAPI( IppStatus, ippsHashMethodSet_SM3, (IppsHashMethod* pMethod) )
-
-IPPAPI( IppStatus, ippsHashStateMethodSet_SM3, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SM3_NI, (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SM3_TT, (IppsHashMethod* pMethod) )
 
 IPP_DEPRECATED(SHA1_DEPRECATED) \
-IPPAPI( IppStatus, ippsHashMethodSet_SHA1, (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA1,    (IppsHashMethod* pMethod) )
 IPP_DEPRECATED(SHA1_DEPRECATED) \
 IPPAPI( IppStatus, ippsHashMethodSet_SHA1_NI, (IppsHashMethod* pMethod) )
 IPP_DEPRECATED(SHA1_DEPRECATED) \
 IPPAPI( IppStatus, ippsHashMethodSet_SHA1_TT, (IppsHashMethod* pMethod) )
 
-IPPAPI( IppStatus, ippsHashMethodSet_SHA256, (IppsHashMethod* pMethod) )
-IPPAPI( IppStatus, ippsHashMethodSet_SHA256_NI, (IppsHashMethod* pMethod) )
-IPPAPI( IppStatus, ippsHashMethodSet_SHA256_TT, (IppsHashMethod* pMethod) )
-
-IPPAPI( IppStatus, ippsHashStateMethodSet_SHA256, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
-IPPAPI( IppStatus, ippsHashStateMethodSet_SHA256_NI, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
-IPPAPI( IppStatus, ippsHashStateMethodSet_SHA256_TT, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
-
-IPPAPI( IppStatus, ippsHashMethodSet_SHA224, (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA224,    (IppsHashMethod* pMethod) )
 IPPAPI( IppStatus, ippsHashMethodSet_SHA224_NI, (IppsHashMethod* pMethod) )
 IPPAPI( IppStatus, ippsHashMethodSet_SHA224_TT, (IppsHashMethod* pMethod) )
 
-IPPAPI( IppStatus, ippsHashStateMethodSet_SHA224, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA256,    (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA256_NI, (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA256_TT, (IppsHashMethod* pMethod) )
+
+IPPAPI( IppStatus, ippsHashMethodSet_SHA384,    (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA384_NI, (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA384_TT, (IppsHashMethod* pMethod) )
+
+IPPAPI( IppStatus, ippsHashMethodSet_SHA512,    (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA512_NI, (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA512_TT, (IppsHashMethod* pMethod) )
+
+IPPAPI( IppStatus, ippsHashMethodSet_SHA512_224,    (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA512_224_NI, (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA512_224_TT, (IppsHashMethod* pMethod) )
+
+IPPAPI( IppStatus, ippsHashMethodSet_SHA512_256,    (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA512_256_NI, (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA512_256_TT, (IppsHashMethod* pMethod) )
+
+IPPAPI( IppStatus, ippsHashMethodSet_SHA3_224,    (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA3_256,    (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA3_384,    (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHA3_512,    (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHAKE128,    (IppsHashMethod* pMethod, int digestBitsize) )
+IPPAPI( IppStatus, ippsHashMethodSet_SHAKE256,    (IppsHashMethod* pMethod, int digestBitsize) )
+
+IPPAPI( IppStatus, ippsHashStateMethodSet_SM3, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SM3_NI, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SM3_TT, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA256,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA256_NI, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA256_TT, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA224,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
 IPPAPI( IppStatus, ippsHashStateMethodSet_SHA224_NI, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
 IPPAPI( IppStatus, ippsHashStateMethodSet_SHA224_TT, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
 
-IPPAPI( IppStatus, ippsHashMethodSet_SHA512, (IppsHashMethod* pMethod) )
-IPPAPI( IppStatus, ippsHashMethodSet_SHA384, (IppsHashMethod* pMethod) )
-IPPAPI( IppStatus, ippsHashMethodSet_SHA512_256, (IppsHashMethod* pMethod) )
-IPPAPI( IppStatus, ippsHashMethodSet_SHA512_224, (IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512_NI, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512_TT, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
 
-IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
-IPPAPI( IppStatus, ippsHashStateMethodSet_SHA384, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
-IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512_256, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
-IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512_224, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA384,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA384_NI, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA384_TT, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512_256,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512_256_NI, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512_256_TT, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512_224,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512_224_NI, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA512_224_TT, (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA3_224,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA3_256,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA3_384,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHA3_512,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHAKE128,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod, int digestBitsize) )
+IPPAPI( IppStatus, ippsHashStateMethodSet_SHAKE256,    (IppsHashState_rmf* pState, IppsHashMethod* pMethod, int digestBitsize) )
 
 IPPAPI(IppStatus, ippsHashGetSize_rmf,(int* pSize))
+IPPAPI(IppStatus, ippsHashGetSizeOptimal_rmf,(int* pSize, const IppsHashMethod* pMethod))
 IPPAPI(IppStatus, ippsHashInit_rmf,(IppsHashState_rmf* pState, const IppsHashMethod* pMethod))
 
 IPPAPI(IppStatus, ippsHashPack_rmf,(const IppsHashState_rmf* pState, Ipp8u* pBuffer, int bufSize))
@@ -569,6 +630,12 @@ IPPAPI(IppStatus, ippsHMACMessage_rmf,(const Ipp8u* pMsg, int msgLen,
                                        Ipp8u* pMD, int mdLen,
                                        const IppsHashMethod* pMethod))
 
+/* HMAC-based Extract-and-Expand Key Derivation Function (HKDF) */
+IPPAPI(IppStatus, ippsHKDF,(const Ipp8u* ikm, int ikmLen,
+                            Ipp8u* okm, int okmLen,
+                            const Ipp8u* salt, int saltLen,
+                            const Ipp8u* info, int infoLen,
+                            const IppsHashMethod* pMethod))
 
 /*
 // =========================================================
@@ -1190,9 +1257,25 @@ IPPAPI(IppStatus, ippsGFpECDecryptSM2_Ext, (Ipp8u *pOut, int maxOutLen,
 #ifdef IPPCP_PREVIEW_XMSS
 
 /* XMSS */
+#define XMSS_DEPRECATED "This function is considered to be renamed due to an ambiguous \
+name. Use ippsXMSSVerifyBufferGetSize instead."
+
+IPP_DEPRECATED(XMSS_DEPRECATED) \
 IPPAPI(IppStatus, ippsXMSSBufferGetSize, (Ipp32s* pSize, Ipp32s maxMessageLength, IppsXMSSAlgo OIDAlgo))
+
+IPPAPI(IppStatus, ippsXMSSVerifyBufferGetSize, (Ipp32s* pSize, Ipp32s maxMessageLength, IppsXMSSAlgo OIDAlgo))
+IPPAPI(IppStatus, ippsXMSSKeyGenBufferGetSize, (Ipp32s* pSize, IppsXMSSAlgo OIDAlgo))
+IPPAPI(IppStatus, ippsXMSSSignBufferGetSize, (Ipp32s* pSize, Ipp32s maxMessageLength, IppsXMSSAlgo OIDAlgo))
+
+IPPAPI(IppStatus, ippsXMSSPrivateKeyStateGetSize, (Ipp32s* pSize, IppsXMSSAlgo OIDAlgo))
 IPPAPI(IppStatus, ippsXMSSPublicKeyStateGetSize, (Ipp32s* pSize, IppsXMSSAlgo OIDAlgo))
 IPPAPI(IppStatus, ippsXMSSSignatureStateGetSize, (Ipp32s* pSize, IppsXMSSAlgo OIDAlgo))
+
+IPPAPI(IppStatus, ippsXMSSInitSignature, (IppsXMSSAlgo OIDAlgo, IppsXMSSSignatureState* pSign))
+IPPAPI(IppStatus, ippsXMSSInitKeyPair, (IppsXMSSAlgo OIDAlgo,
+                                        IppsXMSSPrivateKeyState* pPrvKey,
+                                        IppsXMSSPublicKeyState* pPubKey))
+
 IPPAPI(IppStatus, ippsXMSSSetPublicKeyState, (IppsXMSSAlgo OIDAlgo,
                                               const Ipp8u* pRoot,
                                               const Ipp8u* pSeed,
@@ -1203,6 +1286,17 @@ IPPAPI(IppStatus, ippsXMSSSetSignatureState, (IppsXMSSAlgo OIDAlgo,
                                               const Ipp8u* pOTSSign,
                                               const Ipp8u* pAuthPath,
                                               IppsXMSSSignatureState* pState))
+
+IPPAPI(IppStatus, ippsXMSSKeyGen, (IppsXMSSPrivateKeyState* pPrvKey,
+                                   IppsXMSSPublicKeyState* pPubKey,
+                                   IppBitSupplier rndFunc,
+                                   void* pRndParam,
+                                   Ipp8u* pBuffer))
+IPPAPI(IppStatus, ippsXMSSSign, (const Ipp8u* pMsg,
+                                 const Ipp32s msgLen,
+                                 IppsXMSSPrivateKeyState* pPrvKey,
+                                 IppsXMSSSignatureState* pSign,
+                                 Ipp8u* pBuffer))
 IPPAPI(IppStatus, ippsXMSSVerify, (const Ipp8u* pMsg,
                                    const Ipp32s msgLen,
                                    const IppsXMSSSignatureState* pSign,
