@@ -14,13 +14,16 @@
 * limitations under the License.
 *************************************************************************/
 
+#ifndef IFMA_MEM_FUNCTIONS_H
+#define IFMA_MEM_FUNCTIONS_H
+
 /*
  * Auxiliary functions to set and copy memory
  */
 __MBX_INLINE void CopyBlock(const void* pSrc, void* pDst, int numBytes)
 {
     const int8u* s = (int8u*)pSrc;
-    int8u* d = (int8u*)pDst;
+    int8u* d       = (int8u*)pDst;
     int k;
     for (k = 0; k < numBytes; k++)
         d[k] = s[k];
@@ -33,3 +36,5 @@ __MBX_INLINE void PadBlock(int8u paddingByte, void* pDst, int numBytes)
     for (k = 0; k < numBytes; k++)
         d[k] = paddingByte;
 }
+
+#endif /* IFMA_MEM_FUNCTIONS_H */
