@@ -14,15 +14,16 @@
 * limitations under the License.
 *************************************************************************/
 
-/* 
-// 
+/*
+//
 //  Purpose:
 //     Cryptography Primitive.
 //     Security Hash Standard
 //     Generalized Functionality
-// 
+//
 //  Contents:
 //        ippsHashGetSize_rmf()
+//        ippsHashGetSizeOptimal_rmf()
 //
 */
 
@@ -34,7 +35,7 @@
 /*F*
 //    Name: ippsHashGetSize_rmf
 //
-// Purpose: Returns size (bytes) of IppsHashState state.
+// Purpose: Returns size (bytes) of hash state, universal for supported hash methods.
 //
 // Returns:                Reason:
 //    ippStsNullPtrErr        pSize == NULL
@@ -44,12 +45,35 @@
 //    pSize       pointer to state size
 //
 *F*/
-IPPFUN(IppStatus, ippsHashGetSize_rmf,(int* pSize))
+IPPFUN(IppStatus, ippsHashGetSize_rmf, (int* pSize))
 {
-   /* test pointers */
-   IPP_BAD_PTR1_RET(pSize);
+    /* test pointers */
+    IPP_BAD_PTR1_RET(pSize);
+    *pSize = MAX_HASH_RMF_CONTEXT_SIZE;
 
-   *pSize = sizeof(IppsHashState_rmf);
+    return ippStsNoErr;
+}
 
-   return ippStsNoErr;
+/*F*
+//    Name: ippsHashGetSizeOptimal_rmf
+//
+// Purpose: Returns size (bytes) of hash state depending on method.
+//
+// Returns:                Reason:
+//    ippStsNullPtrErr        pSize == NULL OR pMethod == NULL
+//    ippStsNoErr             no errors
+//
+// Parameters:
+//    pSize       pointer to state size
+//    pMethod     pointer to hash method state
+//
+*F*/
+IPPFUN(IppStatus, ippsHashGetSizeOptimal_rmf, (int* pSize, const IppsHashMethod* pMethod))
+{
+    /* test pointers */
+    IPP_BAD_PTR2_RET(pSize, pMethod);
+
+    *pSize = (int)((Ipp8u)(sizeof(IppsHashState_rmf)) + pMethod->msgBlkSize + pMethod->stateLen);
+
+    return ippStsNoErr;
 }
